library(ggplot2)
library(plyr)
library(scales)

renameVector = c("heft" = "HEFT", "truehp" = "HeteroPrio", "dmdas" = "ECT", "ect" = "ECT", "erls" = "ER-LS", "qa" = "QA", "dep" = "Lower Bound")

algTypes = c("heft" = "Offline", "truehp" = "Offline", "ect" =
	 "Online", "dmdas" = "Offline",
	 "erls"="Online", "qa" = "Online", "HLP" = "Offline", "HLP+spoliation" = "Offline", "dep" = "Bound")

colors = hue_pal()(8)
colors = brewer_pal(type="qual", palette="Dark2")(8)
names(colors) <- sort(unique(revalue(names(algTypes), renameVector)))


args <- commandArgs(trailingOnly = TRUE)

special_modif <- function(df) {
  df[df$algorithm == "HLP", "time"] = df[df$algorithm == "HLP", "time"] + df[df$algorithm == "dep" & !is.na(df$share) & df$share == "dep", "time"]
  df[df$algorithm == "HLP+spoliation", "time"] = df[df$algorithm == "HLP+spoliation", "time"] + df[df$algorithm == "dep" & !is.na(df$share) & df$share == "dep", "time"]
  return(df)
}

t <- read.table(args[1], header=TRUE)
t <- ddply(t, ~ instance+N+m+k, transform, ratio=makespan/max(makespan[isBound=="True"]))
t$algorithm = factor(t$algorithm, levels=c(levels(t$algorithm), "HLP+spoliation", "HLP", "OtherHeft", "OtherDmdas"))
t[t$algorithm == "greedy" & t$stealer ==  1,"algorithm"] = "HLP+spoliation"
t[t$algorithm == "greedy" & t$stealer == -1,"algorithm"] = "HLP"
t <- ddply(t, ~ instance+N+m+k, special_modif)
t[t$algorithm == "heft" & is.na(t$rank),"algorithm"] = "OtherHeft"
t[t$algorithm == "dmdas" & is.na(t$rank),"algorithm"] = "OtherDmdas"


t <- t[t$m %in% c(10, 40) & t$k %in% c(2, 8) & (!t$algorithm %in% c("OtherHeft", "OtherDmdas", "cp")),]
## t <- t[t$algorithm %in% c("heft", "dmdas", "OtherHeft", "OtherDmdas"),]
t$algtype <- revalue(t$algorithm, algTypes)
t$algtype <- factor(t$algtype, levels=c("Offline", "Online", "Bound"))

t$algorithm <- revalue(t$algorithm, renameVector)


tavg <- ddply(t, ~N+algorithm+algtype+isBound, summarize, ratio = mean(ratio), time=mean(time))


p <- ggplot(t[t$isBound == "False",], aes(x=N, y=ratio, color=algorithm, linetype=algtype)) + geom_line()
p <- p + facet_grid(m+k~instance, scales="free")
p <- p + theme(legend.position="bottom")
p <- p + ylab("Makespan ratio to lower bound")
p <- p + xlab("Number of tiles") + scale_x_continuous(breaks=seq(4,64,8))
p <- p + guides(color = guide_legend("Algorithm"), linetype=guide_legend("Type"))
p <- p + scale_color_manual(values=colors)


ggsave(args[2], p, width=7, height=7, device=cairo_pdf)


p <- ggplot(tavg[tavg$isBound == "False",], aes(x=N, y=ratio, color=algorithm, linetype=algtype)) + geom_line()
# p <- p + theme(legend.position="bottom")
p <- p + ylab("Average Makespan ratio to lower bound")
p <- p + xlab("Number of tiles")  + scale_x_continuous(breaks=seq(4,64,4))
p <- p + guides(color = guide_legend("Algorithm"), linetype=guide_legend("Type"))
p <- p + scale_color_manual(values=colors)


ggsave(args[4], p, width=6, height=4, device=cairo_pdf)


# c <- read.table(sub(".dat", ".count", args[1]), header=TRUE)
# tCounts <- merge(t, c)
# tCountsAvg <- ddply(tCounts, ~count+algorithm+algtype+isBound, summarize, time=mean(time))
# tCountsAvgBis <- ddply(tCounts, ~instance + count+algorithm+algtype+isBound, summarize, time=mean(time))
# p <- ggplot(tCountsAvg[tCountsAvg$algorithm != "cp" & tCountsAvg$algorithm != "dep",], aes(x=count, y=time, color=algorithm, linetype=algtype)) + geom_line()
# p <- ggplot(tCountsAvgBis[tCountsAvgBis$algorithm != "cp" & tCountsAvgBis$algorithm != "dep",], aes(x=count, y=time, color=algorithm, linetype=algtype)) + geom_line(aes(group=interaction(algtype, algorithm, instance)))


p <- ggplot(tavg, aes(x=N, y=time, color=algorithm, linetype=algtype)) + geom_line()
# p <- p + facet_grid(m+k~instance, scales="free")
p <- p + scale_y_log10() + scale_x_log10(breaks=c(4,8,16,32,64))
# p <- p + theme(legend.position="bottom")
p <- p + ylab("Time (ms)")
p <- p + xlab("Number of tiles")
p <- p + guides(color = guide_legend("Algorithm"), linetype=guide_legend("Type"))
p <- p + scale_color_manual(values=colors)

ggsave(args[3], p, width=7, height=5, device=cairo_pdf)
