library(ggplot2)
library(plyr)

renameVector = c("zhang" = "Al5", "truehp" = "HeteroPrio", "balest" = "BalEst", "balmks" = "BalMks",
                 "dp3demi" = "DP3/2", "dp2" = "DP2", "dualhp" = "DualHP", "minmin" = "MinMin",
		 "lg" = "LG", "mg" = "MG", "lp" = "LP", "ect" = "ECT", "heft"="Sorted ECT", "clb2c" = "CLB2C", "round" = "Round")

algTypes = c("heft" = "Heuristic", "truehp" = "Heuristic",
	 "ect" = "Online", "lg" = "Online", "lp" = "Lin.Prog.",
	 "mg" = "Online", "zhang" = "Online", "balest" = "Heuristic",
	 "balmks" = "Heuristic", "clb2c" = "Heuristic", "dp2" = "DualApprox",
	 "dp3demi" = "DualApprox", "dualhp" = "DualApprox", "round" = "Lin.Prog.", "minmin"="Heuristic")

args <- commandArgs(trailingOnly = TRUE)

t <- read.table(args[1], header=TRUE)
t <- ddply(t, ~ instance+N+m+k, transform, ratio=makespan/max(makespan[isBound=="True"]))
t$algorithm = factor(t$algorithm, levels=c(levels(t$algorithm), levels(t$indep)))
t[t$algorithm == "indep","algorithm"] = t[t$algorithm == "indep","indep"]
t$algtype <- revalue(t$algorithm, algTypes)
t$algorithm <- revalue(t$algorithm, renameVector)


t <- t[t$m %in% c(10, 40) & t$k %in% c(2, 8) & t$N <= 20,]

gm_mean = function(x, na.rm=TRUE){
  exp(mean(log(x), na.rm=na.rm))
}

p <- ggplot(t[t$isBound == "False" & t$N > 4,], aes(x=algorithm, y=ratio, color=algorithm)) + geom_boxplot()
# p <- p + stat_summary(geom="point", fun.y=gm_mean, color="black")
p <- p + stat_summary(geom="point", fun.y=mean, color="black")
p <- p + facet_grid(. ~ algtype, scales="free_x")
p <- p + theme(axis.text.x = element_text(angle=45, hjust=1))
p <- p + guides(color=FALSE)
p <- p + ylab("Makespan ratio to lower bound")
p <- p + xlab("Algorithm")
p <- p + coord_cartesian(ylim=c(1, 2))

ggsave(args[2], p, width=7, height=5, device=cairo_pdf)

p <- ggplot(t[t$isBound == "False" & t$N > 4,], aes(x=algorithm, y=time, color=algorithm)) + geom_boxplot()
p <- p + facet_grid(. ~ algtype, scales="free_x")
p <- p + theme(axis.text.x = element_text(angle=45, hjust=1))
p <- p + scale_y_log10()
p <- p + guides(color=FALSE)
p <- p + ylab("Time (ms)")
p <- p + xlab("Algorithm")

ggsave(args[3], p, width=7, height=3.5, device=cairo_pdf)


# p <- ggplot(t[t$isBound == "False" & t$N > 4,], aes(x=N, y=ratio, color=algorithm)) + geom_line()
# p <- p + facet_grid(m+k ~ instance, scales="free")
# p <- p + ylab("Makespan ratio to lower bound")
# p <- p + xlab("Number of tiles")
# p <- p + scale_y_log10()

# ggsave(args[2], p, width=7, height=7, device=cairo_pdf)

# p <- ggplot(t[t$isBound == "False" & t$N > 4,], aes(x=N, y=time, color=algorithm)) + geom_line()
# p <- p + facet_grid(m + k ~ instance, scales="free")
# p <- p + ylab("Time (ms)")
# p <- p + xlab("Number of tiles")
# p <- p + scale_y_log10()

# ggsave(args[3], p, width=7, height=7, device=cairo_pdf)

