library(ggplot2)
library(plyr)

renameVector = c("zhang" = "Al5", "truehp" = "HeteroPrio", "balest" = "BalEst", "balmks" = "BalMks",
                 "dp3demi" = "DP3/2", "dp2" = "DP2", "dualhp" = "DualHP", "minmin" = "MinMin",
		 "lg" = "LG", "mg" = "MG", "lp" = "LP", "ect" = "ECT", "heft"="Sorted ECT", "clb2c" = "CLB2C", "round" = "Round")

algTypes = c("heft" = "Heuristic", "truehp" = "Heuristic",
	 "ect" = "Online", "lg" = "Online", "lp" = "Lin.Prog.",
	 "mg" = "Online", "zhang" = "Online", "balest" = "Heuristic",
	 "balmks" = "Heuristic", "clb2c" = "Heuristic", "dp2" = "DualApprox",
	 "dp3demi" = "DualApprox", "dualhp" = "DualApprox", "round" = "Lin.Prog.", "minmin" = "Heuristic")

args <- commandArgs(trailingOnly = TRUE)

t <- read.table(args[1], header=TRUE)
t <- ddply(t, ~ instance+CV_CPU+CV_GPU+rank+m+k, transform, ratio=makespan/max(makespan[isBound=="True"]))
t$algorithm = factor(t$algorithm, levels=c(levels(t$algorithm), levels(t$indep)))
t[t$algorithm == "indep","algorithm"] = t[t$algorithm == "indep","indep"]
t$algtype <- revalue(t$algorithm, algTypes)
t$algorithm <- revalue(t$algorithm, renameVector)

# t <- t[! t$algorithm %in% c("lp", "round"),]

t <- t[t$m %in% c(10, 40) & t$k %in% c(2, 8),]

# & t$algtype %in% c("Heuristic", "DualApprox")
p <- ggplot(t[t$isBound == "False",], aes(x=algorithm, y=ratio, color=algorithm)) + geom_boxplot()
# p <- p + stat_summary(geom="point", fun.y=mean, color="black")
p <- p + facet_grid(CV_CPU + CV_GPU~algtype, scales="free", labeller=label_context)
p <- p + guides(color=FALSE)
p <- p + theme(axis.text.x = element_text(angle=45, hjust=1))
p <- p + ylab("Makespan ratio to lower bound")
p <- p + xlab("Algorithm")

ggsave(args[2], p, width=8, height=6, device=cairo_pdf)

p <- ggplot(t[t$isBound == "False",], aes(x=algorithm, y=time, color=algorithm)) + geom_boxplot()
p <- p + facet_grid(~ algtype, scales="free", labeller=label_context)
p <- p + theme(axis.text.x = element_text(angle=45, hjust=1))
p <- p + scale_y_log10()
p <- p + guides(color=FALSE)
p <- p + ylab("Time (ms)")
p <- p + xlab("Algorithm")

ggsave(args[3], p, width=7, height=3.5, device=cairo_pdf)

