# Rgamma random generator
rgamma_cost <- function(n, mean, sd, allow.zero = TRUE) {
  if (mean == 0 || sd == 0)
    return(rep(mean, n))
  shape <- mean^2 / sd^2
  rate <- mean / sd^2
  values <- rgamma(n, shape, rate)
  if (!allow.zero) {
    values <- values[values != 0]
    while (length(values) != n) {
      values <- c(values, rgamma(n - length(values), shape, rate))
      values <- values[values != 0]
    }
  }
  values
}

n <- 300

outputList <- function(l, file="") {
cat("[", file=file)
cat(l, file=file, sep=", ")
cat("]\n", file=file)

}

generateOne <- function(cv1, cv2, number) {
  costs_CPU <- 15 * rgamma_cost(n, mean = 1, sd = cv1)
  costs_GPU <- rgamma_cost(n, mean = 1, sd = cv2)
  connection <- file(paste("Random", "-", number, "-", cv1, "-", cv2, ".src", sep=""))
  open(connection, open="w")
  writeLines(c("[XX_M_XX, XX_K_XX]"), connection)
  outputList(costs_CPU, file=connection)  
  outputList(costs_GPU, file=connection)
  outputList(seq(0, n-1), file=connection)
  replicate(n, {
     outputList(c(), file=connection)
  })
  close(connection)
}


set.seed(12345)
numbers = 1:100

generateOneCase <- function(cv1, cv2) {
 lapply(numbers, function(i) { generateOne(cv1, cv2, i) })
}

invisible(outer(c(0.2, 1), c(0.2, 1), function(X, Y) { mapply(generateOneCase, X, Y, SIMPLIFY=FALSE);}))


