#!/usr/bin/env python3 

import scripts.resultStorage as resultStorage
from collections import Iterable
from scripts.dagCommon import *

def getFilePrefix(i): 
    if i.insType == "Cholesky":
        return (dirPrefix + "inputs/%s-%s" % (i.insType, i.N))
    elif i.insType == "QR":
        return (dirPrefix + "inputs/%s-ib128-%s" % (i.insType, i.N))
    elif i.insType == "LU":
        return (dirPrefix + "inputs/%s-nopiv-ib96-%s" % (i.insType, i.N))
    else:
        print("Unknown instance type %s" % i.insType, file=sys.stderr)
        exit

(datFile, rawFile) = getInputFile("bordeaux.dat")        

DagStore = resultStorage.MakeStorage(["N"], getFilePrefix, ["/home/eyraud/Travail/StarPU/pmtool/cmake-build-cplex/pmtool"])
store = DagStore(rawFile)

instancesCholesky =  store.makeInstances("Cholesky", N=map(str, list(range(4, 65, 4)) + list(range(6, 20, 4))), m = [10, 20, 40], k = [2, 4, 8])
instancesQR = store.makeInstances("QR", N=map(str, list(range(4, 65, 4)) + list(range(6, 20, 4))), m = [10, 20, 40], k = [2, 4, 8])
instancesLU = store.makeInstances("LU", N=map(str, range(4, 65, 4)), m = [10, 20, 40], k = [2, 4, 8])

if __name__ == "__main__":
    store.updateFile(store.allCombinations(instancesCholesky, algorithms), pred=includeDepBoundEvenIfValidAnswerWhenGreedyHasNot(store))
    store.updateFile(store.allCombinations(instancesQR, algorithms), pred=includeDepBoundEvenIfValidAnswerWhenGreedyHasNot(store))
    store.updateFile(store.allCombinations(instancesLU, algorithms), pred=includeDepBoundEvenIfValidAnswerWhenGreedyHasNot(store))
    
    store.displayFileContents(file=datFile)

    # Can be de-commented to be able to plot the number of tasks of each instance
    # countFile = os.path.splitext(datFile)[0] + ".count"
    # store.countTasks(instancesCholesky + instancesQR + instancesLU, file=countFile)
