#!/usr/bin/env python3 

import scripts.resultStorage as resultStorage
from collections import Iterable
from scripts.dagCommon import dirPrefix, getInputFile

def getFilePrefix(i): 
    if i.insType == "Cholesky":
        return (dirPrefix + "inputs/%s-%s" % (i.insType, i.N))
    elif i.insType == "QR":
        return (dirPrefix + "inputs/%s-ib128-%s" % (i.insType, i.N))
    elif i.insType == "LU":
        return (dirPrefix + "inputs/%s-nopiv-ib96-%s" % (i.insType, i.N))
    else:
        print("Unknown instance type %s" % i.insType, file=sys.stderr)
        exit

(datFile, rawFile) = getInputFile("bordeauxIndep.dat")        

DagStore = resultStorage.MakeStorage(["N"], getFilePrefix, ["/home/eyraud/Travail/StarPU/pmtool/cmake-build-cplex/pmtool", "--no-dep"])
store = DagStore(rawFile)

instancesCholesky =  store.makeInstances("Cholesky", N=map(str, list(range(8, 21, 4)) + list(range(6, 20, 4))), m = [10, 40], k = [2, 8])
instancesQR = store.makeInstances("QR", N=map(str, list(range(8, 21, 4)) + list(range(6, 20, 4))), m = [10, 40], k = [2, 8])
instancesLU = store.makeInstances("LU", N=map(str, range(8, 21, 4)), m = [10, 40], k = [2, 8])

algorithms = [ resultStorage.Algorithm(alg = "heft", isBound=False, params="rank=heft"),
               resultStorage.Algorithm(alg = "truehp", isBound=False, params="") ]
algorithms += [ resultStorage.Algorithm(alg = "indep", isBound=False, params="indep="+n+":style=strict") for n in ["dualhp", "balest", "balmks", "round", "clb2c", "minmin"] ]
algorithms += [ resultStorage.Algorithm(alg = "indep", isBound=False, params="cplex=true:indep="+n+":style=strict") for n in ["dp2", "dp3demi"] ]
algorithms += [ resultStorage.Algorithm(alg = a, isBound=False, params="") for a in ["zhang", "lg", "mg", "ect"] ]
algorithms += [ resultStorage.Algorithm(alg = "lp", isBound = False, params="gap=0.1") ]
algorithms += [ resultStorage.Algorithm(alg = "area", isBound = True, params="hybrid=no") ]
algorithms += [ resultStorage.Algorithm(alg = "cp", isBound = True, params="") ]

if __name__ == "__main__":
    store.updateFile(store.allCombinations(instancesCholesky, algorithms))
    store.updateFile(store.allCombinations(instancesQR, algorithms))
    store.updateFile(store.allCombinations(instancesLU, algorithms))
    
    store.displayFileContents(file=datFile)
