import scripts.resultStorage as resultStorage
import sys
import os.path

dirPrefix = "./"

def getInputFile(default = None):
    if len(sys.argv) >= 2:
        datFile = sys.argv[1]
    else:
        if default: 
            datFile = dirPrefix + "results/" + default
        else:
            print("No input file specified on command line, and no default", file=stderr)
            return None
    rawFile = os.path.splitext(datFile)[0] + ".raw"
    return (datFile, rawFile)

algorithms = [ resultStorage.Algorithm(alg = n, isBound=False, params="") for n in ["heft", "dmdas", "qa", "erls", "ect"] ]
algorithms.append(resultStorage.Algorithm(alg = "dmdas", isBound=False, params="rank=unit"))
algorithms.append(resultStorage.Algorithm(alg = "heft", isBound=False, params="rank=heft"))
algorithms.append(resultStorage.Algorithm(alg = "truehp", isBound=False, params="steal=prio"))
algorithms.extend(resultStorage.makeAlgorithms("greedy", ("key", ["dep[alloc]"]), ("stealer", ["1", "-1"])))
algorithms.append(resultStorage.Algorithm(alg = "dep", isBound=True, params="hybrid=no:share=dep"))
algorithms.append(resultStorage.Algorithm(alg = "cp", isBound = True, params=""))


def includeDepBoundEvenIfValidAnswerWhenGreedyHasNot(store):
    def result(q, data):
        if q.isBound:
            greedyStealer = q._replace(isBound=False, alg = "greedy", params="key=dep[alloc]:stealer=1")
            greedyNoStealer = q._replace(isBound=False, alg = "greedy", params="key=dep[alloc]:stealer=-1")
            if not (store.hasValidAnswer(greedyStealer, data) and store.hasValidAnswer(greedyNoStealer, data)):
                return True
        return not store.hasValidAnswer(q, data)
    return result

