#!/usr/bin/env python3 

import scripts.resultStorage as resultStorage
from collections import Iterable
from scripts.dagCommon import dirPrefix, getInputFile
    
def getFilePrefix(i): 
    if i.insType == "Random":
        return (dirPrefix + "inputs/lyon/Random-%s-%s-%s" % (i.rank, i.CV_CPU, i.CV_GPU))
    else:
        print("Unknown instance type %s" % i.insType, file=sys.stderr)
        exit

(datFile, rawFile) = getInputFile("randomIndep.dat")        

IndepStore = resultStorage.MakeStorage(["rank", "CV_CPU", "CV_GPU"],
                                       getFilePrefix,
                                       ["/home/eyraud/Travail/StarPU/pmtool/cmake-build-cplex/pmtool", "--no-dep"])

store = IndepStore(rawFile)

allInstances = store.makeInstances("Random", rank=map(str, range(1, 100)), CV_CPU=["0.2", "1"], CV_GPU=["0.2", "1"], m=[10, 40], k = [2, 8])

algorithms = [ resultStorage.Algorithm(alg = "heft", isBound=False, params="rank=heft"),
               resultStorage.Algorithm(alg = "truehp", isBound=False, params="") ]

# algorithms += [ resultStorage.Algorithm(alg = "indep", isBound=False, params="indep="+n+":style=strict") for n in ["dp2", "dualhp", "balest", "accel", "zhang", "round", "clb2c"] ]
algorithms += [ resultStorage.Algorithm(alg = "indep", isBound=False, params="indep="+n+":style=strict") for n in ["dualhp", "balest", "round", "clb2c", "balmks", "minmin"] ]
algorithms += [ resultStorage.Algorithm(alg = "indep", isBound=False, params="cplex=true:indep="+n+":style=strict") for n in ["dp2", "dp3demi"] ]
algorithms += [ resultStorage.Algorithm(alg = a, isBound=False, params="") for a in ["zhang", "lg", "mg", "ect"] ]
# algorithms += [ resultStorage.Algorithm(alg = "lp", isBound = False, params="gap=0.1") ]
algorithms += [ resultStorage.Algorithm(alg = "area", isBound = True, params="hybrid=no") ]
algorithms += [ resultStorage.Algorithm(alg = "cp", isBound = True, params="") ]

if __name__ == "__main__":
    store.updateFile(store.allCombinations(allInstances, algorithms))
    store.displayFileContents(file=datFile)
    
